analysis

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 21, 2020 License: MIT Imports: 12 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Report

type Report struct {
	SyllableAnalysis      SyllableDistributionAnalysis
	SyllableRatioAnalysis SyllableRatioAnalysis
}

func Build

func Build(document flesch.Document) (Report, error)

type SyllableDistributionAnalysis

type SyllableDistributionAnalysis struct {
	// Number of words that have a number of syllables
	// e.g. [4]6 would mean there are 6 words with 4 syllables
	SyllableDistribution map[int]int
	KeyOrder             []int
	ChartPath            string
}

func BuildSyllableAnalysis

func BuildSyllableAnalysis(document flesch.Document) (SyllableDistributionAnalysis, error)

type SyllableRatioAnalysis

type SyllableRatioAnalysis struct {
	SyllableRatio map[string]float64
	KeyOrder      []string
	ChartPath     string
}

SyllableRatioAnalysis shows the top words with the highest ratio of characters to syllables

func BuildSyllableRatioAnalysis

func BuildSyllableRatioAnalysis(document flesch.Document) (SyllableRatioAnalysis, error)

Jump to